@@ -209,6 +209,9 @@ impl<'a, INPUTPASSPORTELEMENT: TDInputPassportElement> TDInputPassportElement fo
 impl<'a, INPUTPASSPORTELEMENTERRORSOURCE: TDInputPassportElementErrorSource> TDInputPassportElementErrorSource for &'a INPUTPASSPORTELEMENTERRORSOURCE {}
 impl<'a, INPUTPASSPORTELEMENTERRORSOURCE: TDInputPassportElementErrorSource> TDInputPassportElementErrorSource for &'a mut INPUTPASSPORTELEMENTERRORSOURCE {}
 
+impl<'a, JSONVALUE: TDJsonValue> TDJsonValue for &'a JSONVALUE {}
+impl<'a, JSONVALUE: TDJsonValue> TDJsonValue for &'a mut JSONVALUE {}
+
 impl<'a, KEYBOARDBUTTONTYPE: TDKeyboardButtonType> TDKeyboardButtonType for &'a KEYBOARDBUTTONTYPE {}
 impl<'a, KEYBOARDBUTTONTYPE: TDKeyboardButtonType> TDKeyboardButtonType for &'a mut KEYBOARDBUTTONTYPE {}
 
@@ -218,14 +221,17 @@ impl<'a, LANGUAGEPACKSTRINGVALUE: TDLanguagePackStringValue> TDLanguagePackStrin
 impl<'a, LINKSTATE: TDLinkState> TDLinkState for &'a LINKSTATE {}
 impl<'a, LINKSTATE: TDLinkState> TDLinkState for &'a mut LINKSTATE {}
 
+impl<'a, LOGSTREAM: TDLogStream> TDLogStream for &'a LOGSTREAM {}
+impl<'a, LOGSTREAM: TDLogStream> TDLogStream for &'a mut LOGSTREAM {}
+
 impl<'a, MASKPOINT: TDMaskPoint> TDMaskPoint for &'a MASKPOINT {}
 impl<'a, MASKPOINT: TDMaskPoint> TDMaskPoint for &'a mut MASKPOINT {}
 
 impl<'a, MESSAGECONTENT: TDMessageContent> TDMessageContent for &'a MESSAGECONTENT {}
 impl<'a, MESSAGECONTENT: TDMessageContent> TDMessageContent for &'a mut MESSAGECONTENT {}
 
-impl<'a, MESSAGEFORWARDINFO: TDMessageForwardInfo> TDMessageForwardInfo for &'a MESSAGEFORWARDINFO {}
-impl<'a, MESSAGEFORWARDINFO: TDMessageForwardInfo> TDMessageForwardInfo for &'a mut MESSAGEFORWARDINFO {}
+impl<'a, MESSAGEFORWARDORIGIN: TDMessageForwardOrigin> TDMessageForwardOrigin for &'a MESSAGEFORWARDORIGIN {}
+impl<'a, MESSAGEFORWARDORIGIN: TDMessageForwardOrigin> TDMessageForwardOrigin for &'a mut MESSAGEFORWARDORIGIN {}
 
 impl<'a, MESSAGESENDINGSTATE: TDMessageSendingState> TDMessageSendingState for &'a MESSAGESENDINGSTATE {}
 impl<'a, MESSAGESENDINGSTATE: TDMessageSendingState> TDMessageSendingState for &'a mut MESSAGESENDINGSTATE {}
@@ -236,15 +242,27 @@ impl<'a, NETWORKSTATISTICSENTRY: TDNetworkStatisticsEntry> TDNetworkStatisticsEn
 impl<'a, NETWORKTYPE: TDNetworkType> TDNetworkType for &'a NETWORKTYPE {}
 impl<'a, NETWORKTYPE: TDNetworkType> TDNetworkType for &'a mut NETWORKTYPE {}
 
+impl<'a, NOTIFICATIONGROUPTYPE: TDNotificationGroupType> TDNotificationGroupType for &'a NOTIFICATIONGROUPTYPE {}
+impl<'a, NOTIFICATIONGROUPTYPE: TDNotificationGroupType> TDNotificationGroupType for &'a mut NOTIFICATIONGROUPTYPE {}
+
 impl<'a, NOTIFICATIONSETTINGSSCOPE: TDNotificationSettingsScope> TDNotificationSettingsScope for &'a NOTIFICATIONSETTINGSSCOPE {}
 impl<'a, NOTIFICATIONSETTINGSSCOPE: TDNotificationSettingsScope> TDNotificationSettingsScope for &'a mut NOTIFICATIONSETTINGSSCOPE {}
 
+impl<'a, NOTIFICATIONTYPE: TDNotificationType> TDNotificationType for &'a NOTIFICATIONTYPE {}
+impl<'a, NOTIFICATIONTYPE: TDNotificationType> TDNotificationType for &'a mut NOTIFICATIONTYPE {}
+
 impl<'a, OPTIONVALUE: TDOptionValue> TDOptionValue for &'a OPTIONVALUE {}
 impl<'a, OPTIONVALUE: TDOptionValue> TDOptionValue for &'a mut OPTIONVALUE {}
 
 impl<'a, PAGEBLOCK: TDPageBlock> TDPageBlock for &'a PAGEBLOCK {}
 impl<'a, PAGEBLOCK: TDPageBlock> TDPageBlock for &'a mut PAGEBLOCK {}
 
+impl<'a, PAGEBLOCKHORIZONTALALIGNMENT: TDPageBlockHorizontalAlignment> TDPageBlockHorizontalAlignment for &'a PAGEBLOCKHORIZONTALALIGNMENT {}
+impl<'a, PAGEBLOCKHORIZONTALALIGNMENT: TDPageBlockHorizontalAlignment> TDPageBlockHorizontalAlignment for &'a mut PAGEBLOCKHORIZONTALALIGNMENT {}
+
+impl<'a, PAGEBLOCKVERTICALALIGNMENT: TDPageBlockVerticalAlignment> TDPageBlockVerticalAlignment for &'a PAGEBLOCKVERTICALALIGNMENT {}
+impl<'a, PAGEBLOCKVERTICALALIGNMENT: TDPageBlockVerticalAlignment> TDPageBlockVerticalAlignment for &'a mut PAGEBLOCKVERTICALALIGNMENT {}
+
 impl<'a, PASSPORTELEMENT: TDPassportElement> TDPassportElement for &'a PASSPORTELEMENT {}
 impl<'a, PASSPORTELEMENT: TDPassportElement> TDPassportElement for &'a mut PASSPORTELEMENT {}
 
@@ -257,6 +275,9 @@ impl<'a, PASSPORTELEMENTTYPE: TDPassportElementType> TDPassportElementType for &
 impl<'a, PROXYTYPE: TDProxyType> TDProxyType for &'a PROXYTYPE {}
 impl<'a, PROXYTYPE: TDProxyType> TDProxyType for &'a mut PROXYTYPE {}
 
+impl<'a, PUSHMESSAGECONTENT: TDPushMessageContent> TDPushMessageContent for &'a PUSHMESSAGECONTENT {}
+impl<'a, PUSHMESSAGECONTENT: TDPushMessageContent> TDPushMessageContent for &'a mut PUSHMESSAGECONTENT {}
+
 impl<'a, REPLYMARKUP: TDReplyMarkup> TDReplyMarkup for &'a REPLYMARKUP {}
 impl<'a, REPLYMARKUP: TDReplyMarkup> TDReplyMarkup for &'a mut REPLYMARKUP {}
 
@@ -303,6 +324,7 @@ impl<'a, USERTYPE: TDUserType> TDUserType for &'a mut USERTYPE {}
 #[derive(Debug, Clone)]
 pub enum TdType {
   TestUseUpdate(TestUseUpdate),
+  UpdateActiveNotifications(UpdateActiveNotifications),
   UpdateAuthorizationState(UpdateAuthorizationState),
   UpdateBasicGroup(UpdateBasicGroup),
   UpdateBasicGroupFullInfo(UpdateBasicGroupFullInfo),
@@ -314,8 +336,10 @@ pub enum TdType {
   UpdateChatIsSponsored(UpdateChatIsSponsored),
   UpdateChatLastMessage(UpdateChatLastMessage),
   UpdateChatNotificationSettings(UpdateChatNotificationSettings),
+  UpdateChatOnlineMemberCount(UpdateChatOnlineMemberCount),
   UpdateChatOrder(UpdateChatOrder),
   UpdateChatPhoto(UpdateChatPhoto),
+  UpdateChatPinnedMessage(UpdateChatPinnedMessage),
   UpdateChatReadInbox(UpdateChatReadInbox),
   UpdateChatReadOutbox(UpdateChatReadOutbox),
   UpdateChatReplyMarkup(UpdateChatReplyMarkup),
@@ -327,6 +351,7 @@ pub enum TdType {
   UpdateFile(UpdateFile),
   UpdateFileGenerationStart(UpdateFileGenerationStart),
   UpdateFileGenerationStop(UpdateFileGenerationStop),
+  UpdateHavePendingNotifications(UpdateHavePendingNotifications),
   UpdateInstalledStickerSets(UpdateInstalledStickerSets),
   UpdateLanguagePackStrings(UpdateLanguagePackStrings),
   UpdateMessageContent(UpdateMessageContent),
@@ -347,7 +372,10 @@ pub enum TdType {
   UpdateNewMessage(UpdateNewMessage),
   UpdateNewPreCheckoutQuery(UpdateNewPreCheckoutQuery),
   UpdateNewShippingQuery(UpdateNewShippingQuery),
+  UpdateNotification(UpdateNotification),
+  UpdateNotificationGroup(UpdateNotificationGroup),
   UpdateOption(UpdateOption),
+  UpdatePoll(UpdatePoll),
   UpdateRecentStickers(UpdateRecentStickers),
   UpdateSavedAnimations(UpdateSavedAnimations),
   UpdateScopeNotificationSettings(UpdateScopeNotificationSettings),
@@ -367,7 +395,9 @@ pub enum TdType {
 
   AuthorizationState(AuthorizationState),
   CheckChatUsernameResult(CheckChatUsernameResult),
+  JsonValue(JsonValue),
   LanguagePackStringValue(LanguagePackStringValue),
+  LogStream(LogStream),
   OptionValue(OptionValue),
   PassportElement(PassportElement),
   Update(Update),
@@ -389,18 +419,24 @@ pub enum TdType {
   ConnectedWebsites(ConnectedWebsites),
   Count(Count),
   CustomRequestResult(CustomRequestResult),
+  DatabaseStatistics(DatabaseStatistics),
   DeepLinkInfo(DeepLinkInfo),
   EmailAddressAuthenticationCodeInfo(EmailAddressAuthenticationCodeInfo),
   Error(Error),
   File(File),
+  FilePart(FilePart),
   FormattedText(FormattedText),
   FoundMessages(FoundMessages),
   GameHighScores(GameHighScores),
   Hashtags(Hashtags),
+  HttpUrl(HttpUrl),
   ImportedContacts(ImportedContacts),
   InlineQueryResults(InlineQueryResults),
+  LanguagePackInfo(LanguagePackInfo),
   LanguagePackStrings(LanguagePackStrings),
   LocalizationTargetInfo(LocalizationTargetInfo),
+  LogTags(LogTags),
+  LogVerbosityLevel(LogVerbosityLevel),
   Message(Message),
   Messages(Messages),
   NetworkStatistics(NetworkStatistics),
@@ -408,6 +444,7 @@ pub enum TdType {
   OrderInfo(OrderInfo),
   PassportAuthorizationForm(PassportAuthorizationForm),
   PassportElements(PassportElements),
+  PassportElementsWithErrors(PassportElementsWithErrors),
   PasswordState(PasswordState),
   PaymentForm(PaymentForm),
   PaymentReceipt(PaymentReceipt),
@@ -415,6 +452,7 @@ pub enum TdType {
   Proxies(Proxies),
   Proxy(Proxy),
   PublicMessageLink(PublicMessageLink),
+  PushReceiverId(PushReceiverId),
   RecoveryEmailAddress(RecoveryEmailAddress),
   ScopeNotificationSettings(ScopeNotificationSettings),
   Seconds(Seconds),
@@ -439,6 +477,7 @@ pub enum TdType {
   TestVectorStringObject(TestVectorStringObject),
   Text(Text),
   TextEntities(TextEntities),
+  Updates(Updates),
   User(User),
   UserFullInfo(UserFullInfo),
   UserPrivacySettingRules(UserPrivacySettingRules),
@@ -456,6 +495,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
     rtd_enum_deserialize!(
       TdType,
   (testUseUpdate, TestUseUpdate);
+  (updateActiveNotifications, UpdateActiveNotifications);
   (updateAuthorizationState, UpdateAuthorizationState);
   (updateBasicGroup, UpdateBasicGroup);
   (updateBasicGroupFullInfo, UpdateBasicGroupFullInfo);
@@ -467,8 +507,10 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateChatIsSponsored, UpdateChatIsSponsored);
   (updateChatLastMessage, UpdateChatLastMessage);
   (updateChatNotificationSettings, UpdateChatNotificationSettings);
+  (updateChatOnlineMemberCount, UpdateChatOnlineMemberCount);
   (updateChatOrder, UpdateChatOrder);
   (updateChatPhoto, UpdateChatPhoto);
+  (updateChatPinnedMessage, UpdateChatPinnedMessage);
   (updateChatReadInbox, UpdateChatReadInbox);
   (updateChatReadOutbox, UpdateChatReadOutbox);
   (updateChatReplyMarkup, UpdateChatReplyMarkup);
@@ -480,6 +522,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateFile, UpdateFile);
   (updateFileGenerationStart, UpdateFileGenerationStart);
   (updateFileGenerationStop, UpdateFileGenerationStop);
+  (updateHavePendingNotifications, UpdateHavePendingNotifications);
   (updateInstalledStickerSets, UpdateInstalledStickerSets);
   (updateLanguagePackStrings, UpdateLanguagePackStrings);
   (updateMessageContent, UpdateMessageContent);
@@ -500,7 +543,10 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (updateNewMessage, UpdateNewMessage);
   (updateNewPreCheckoutQuery, UpdateNewPreCheckoutQuery);
   (updateNewShippingQuery, UpdateNewShippingQuery);
+  (updateNotification, UpdateNotification);
+  (updateNotificationGroup, UpdateNotificationGroup);
   (updateOption, UpdateOption);
+  (updatePoll, UpdatePoll);
   (updateRecentStickers, UpdateRecentStickers);
   (updateSavedAnimations, UpdateSavedAnimations);
   (updateScopeNotificationSettings, UpdateScopeNotificationSettings);
@@ -520,7 +566,9 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
 
   (AuthorizationState, AuthorizationState);
   (CheckChatUsernameResult, CheckChatUsernameResult);
+  (JsonValue, JsonValue);
   (LanguagePackStringValue, LanguagePackStringValue);
+  (LogStream, LogStream);
   (OptionValue, OptionValue);
   (PassportElement, PassportElement);
   (Update, Update);
@@ -542,18 +590,24 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (connectedWebsites, ConnectedWebsites);
   (count, Count);
   (customRequestResult, CustomRequestResult);
+  (databaseStatistics, DatabaseStatistics);
   (deepLinkInfo, DeepLinkInfo);
   (emailAddressAuthenticationCodeInfo, EmailAddressAuthenticationCodeInfo);
   (error, Error);
   (file, File);
+  (filePart, FilePart);
   (formattedText, FormattedText);
   (foundMessages, FoundMessages);
   (gameHighScores, GameHighScores);
   (hashtags, Hashtags);
+  (httpUrl, HttpUrl);
   (importedContacts, ImportedContacts);
   (inlineQueryResults, InlineQueryResults);
+  (languagePackInfo, LanguagePackInfo);
   (languagePackStrings, LanguagePackStrings);
   (localizationTargetInfo, LocalizationTargetInfo);
+  (logTags, LogTags);
+  (logVerbosityLevel, LogVerbosityLevel);
   (message, Message);
   (messages, Messages);
   (networkStatistics, NetworkStatistics);
@@ -561,6 +615,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (orderInfo, OrderInfo);
   (passportAuthorizationForm, PassportAuthorizationForm);
   (passportElements, PassportElements);
+  (passportElementsWithErrors, PassportElementsWithErrors);
   (passwordState, PasswordState);
   (paymentForm, PaymentForm);
   (paymentReceipt, PaymentReceipt);
@@ -568,6 +623,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (proxies, Proxies);
   (proxy, Proxy);
   (publicMessageLink, PublicMessageLink);
+  (pushReceiverId, PushReceiverId);
   (recoveryEmailAddress, RecoveryEmailAddress);
   (scopeNotificationSettings, ScopeNotificationSettings);
   (seconds, Seconds);
@@ -592,6 +648,7 @@ fn deserialize<D>(deserializer: D) -> Result<TdType, D::Error> where D: Deserial
   (testVectorStringObject, TestVectorStringObject);
   (text, Text);
   (textEntities, TextEntities);
+  (updates, Updates);
   (user, User);
   (userFullInfo, UserFullInfo);
   (userPrivacySettingRules, UserPrivacySettingRules);
@@ -612,6 +669,7 @@ impl RObject for TdType {
   fn td_name(&self) -> &'static str {
     match self {
       Self::TestUseUpdate(value) => value.td_name(),
+      Self::UpdateActiveNotifications(value) => value.td_name(),
       Self::UpdateAuthorizationState(value) => value.td_name(),
       Self::UpdateBasicGroup(value) => value.td_name(),
       Self::UpdateBasicGroupFullInfo(value) => value.td_name(),
@@ -623,8 +681,10 @@ impl RObject for TdType {
       Self::UpdateChatIsSponsored(value) => value.td_name(),
       Self::UpdateChatLastMessage(value) => value.td_name(),
       Self::UpdateChatNotificationSettings(value) => value.td_name(),
+      Self::UpdateChatOnlineMemberCount(value) => value.td_name(),
       Self::UpdateChatOrder(value) => value.td_name(),
       Self::UpdateChatPhoto(value) => value.td_name(),
+      Self::UpdateChatPinnedMessage(value) => value.td_name(),
       Self::UpdateChatReadInbox(value) => value.td_name(),
       Self::UpdateChatReadOutbox(value) => value.td_name(),
       Self::UpdateChatReplyMarkup(value) => value.td_name(),
@@ -636,6 +696,7 @@ impl RObject for TdType {
       Self::UpdateFile(value) => value.td_name(),
       Self::UpdateFileGenerationStart(value) => value.td_name(),
       Self::UpdateFileGenerationStop(value) => value.td_name(),
+      Self::UpdateHavePendingNotifications(value) => value.td_name(),
       Self::UpdateInstalledStickerSets(value) => value.td_name(),
       Self::UpdateLanguagePackStrings(value) => value.td_name(),
       Self::UpdateMessageContent(value) => value.td_name(),
@@ -656,7 +717,10 @@ impl RObject for TdType {
       Self::UpdateNewMessage(value) => value.td_name(),
       Self::UpdateNewPreCheckoutQuery(value) => value.td_name(),
       Self::UpdateNewShippingQuery(value) => value.td_name(),
+      Self::UpdateNotification(value) => value.td_name(),
+      Self::UpdateNotificationGroup(value) => value.td_name(),
       Self::UpdateOption(value) => value.td_name(),
+      Self::UpdatePoll(value) => value.td_name(),
       Self::UpdateRecentStickers(value) => value.td_name(),
       Self::UpdateSavedAnimations(value) => value.td_name(),
       Self::UpdateScopeNotificationSettings(value) => value.td_name(),
@@ -676,7 +740,9 @@ impl RObject for TdType {
     
       Self::AuthorizationState(value) => value.td_name(),
       Self::CheckChatUsernameResult(value) => value.td_name(),
+      Self::JsonValue(value) => value.td_name(),
       Self::LanguagePackStringValue(value) => value.td_name(),
+      Self::LogStream(value) => value.td_name(),
       Self::OptionValue(value) => value.td_name(),
       Self::PassportElement(value) => value.td_name(),
       Self::Update(value) => value.td_name(),
@@ -698,18 +764,24 @@ impl RObject for TdType {
       Self::ConnectedWebsites(value) => value.td_name(),
       Self::Count(value) => value.td_name(),
       Self::CustomRequestResult(value) => value.td_name(),
+      Self::DatabaseStatistics(value) => value.td_name(),
       Self::DeepLinkInfo(value) => value.td_name(),
       Self::EmailAddressAuthenticationCodeInfo(value) => value.td_name(),
       Self::Error(value) => value.td_name(),
       Self::File(value) => value.td_name(),
+      Self::FilePart(value) => value.td_name(),
       Self::FormattedText(value) => value.td_name(),
       Self::FoundMessages(value) => value.td_name(),
       Self::GameHighScores(value) => value.td_name(),
       Self::Hashtags(value) => value.td_name(),
+      Self::HttpUrl(value) => value.td_name(),
       Self::ImportedContacts(value) => value.td_name(),
       Self::InlineQueryResults(value) => value.td_name(),
+      Self::LanguagePackInfo(value) => value.td_name(),
       Self::LanguagePackStrings(value) => value.td_name(),
       Self::LocalizationTargetInfo(value) => value.td_name(),
+      Self::LogTags(value) => value.td_name(),
+      Self::LogVerbosityLevel(value) => value.td_name(),
       Self::Message(value) => value.td_name(),
       Self::Messages(value) => value.td_name(),
       Self::NetworkStatistics(value) => value.td_name(),
@@ -717,6 +789,7 @@ impl RObject for TdType {
       Self::OrderInfo(value) => value.td_name(),
       Self::PassportAuthorizationForm(value) => value.td_name(),
       Self::PassportElements(value) => value.td_name(),
+      Self::PassportElementsWithErrors(value) => value.td_name(),
       Self::PasswordState(value) => value.td_name(),
       Self::PaymentForm(value) => value.td_name(),
       Self::PaymentReceipt(value) => value.td_name(),
@@ -724,6 +797,7 @@ impl RObject for TdType {
       Self::Proxies(value) => value.td_name(),
       Self::Proxy(value) => value.td_name(),
       Self::PublicMessageLink(value) => value.td_name(),
+      Self::PushReceiverId(value) => value.td_name(),
       Self::RecoveryEmailAddress(value) => value.td_name(),
       Self::ScopeNotificationSettings(value) => value.td_name(),
       Self::Seconds(value) => value.td_name(),
@@ -748,6 +822,7 @@ impl RObject for TdType {
       Self::TestVectorStringObject(value) => value.td_name(),
       Self::Text(value) => value.td_name(),
       Self::TextEntities(value) => value.td_name(),
+      Self::Updates(value) => value.td_name(),
       Self::User(value) => value.td_name(),
       Self::UserFullInfo(value) => value.td_name(),
       Self::UserPrivacySettingRules(value) => value.td_name(),
@@ -764,6 +839,7 @@ impl RObject for TdType {
   fn extra(&self) -> Option<String> {
     match self {
         Self::TestUseUpdate(value) => value.extra(),
+        Self::UpdateActiveNotifications(value) => value.extra(),
         Self::UpdateAuthorizationState(value) => value.extra(),
         Self::UpdateBasicGroup(value) => value.extra(),
         Self::UpdateBasicGroupFullInfo(value) => value.extra(),
@@ -775,8 +851,10 @@ impl RObject for TdType {
         Self::UpdateChatIsSponsored(value) => value.extra(),
         Self::UpdateChatLastMessage(value) => value.extra(),
         Self::UpdateChatNotificationSettings(value) => value.extra(),
+        Self::UpdateChatOnlineMemberCount(value) => value.extra(),
         Self::UpdateChatOrder(value) => value.extra(),
         Self::UpdateChatPhoto(value) => value.extra(),
+        Self::UpdateChatPinnedMessage(value) => value.extra(),
         Self::UpdateChatReadInbox(value) => value.extra(),
         Self::UpdateChatReadOutbox(value) => value.extra(),
         Self::UpdateChatReplyMarkup(value) => value.extra(),
@@ -788,6 +866,7 @@ impl RObject for TdType {
         Self::UpdateFile(value) => value.extra(),
         Self::UpdateFileGenerationStart(value) => value.extra(),
         Self::UpdateFileGenerationStop(value) => value.extra(),
+        Self::UpdateHavePendingNotifications(value) => value.extra(),
         Self::UpdateInstalledStickerSets(value) => value.extra(),
         Self::UpdateLanguagePackStrings(value) => value.extra(),
         Self::UpdateMessageContent(value) => value.extra(),
@@ -808,7 +887,10 @@ impl RObject for TdType {
         Self::UpdateNewMessage(value) => value.extra(),
         Self::UpdateNewPreCheckoutQuery(value) => value.extra(),
         Self::UpdateNewShippingQuery(value) => value.extra(),
+        Self::UpdateNotification(value) => value.extra(),
+        Self::UpdateNotificationGroup(value) => value.extra(),
         Self::UpdateOption(value) => value.extra(),
+        Self::UpdatePoll(value) => value.extra(),
         Self::UpdateRecentStickers(value) => value.extra(),
         Self::UpdateSavedAnimations(value) => value.extra(),
         Self::UpdateScopeNotificationSettings(value) => value.extra(),
@@ -828,7 +910,9 @@ impl RObject for TdType {
       
         Self::AuthorizationState(value) => value.extra(),
         Self::CheckChatUsernameResult(value) => value.extra(),
+        Self::JsonValue(value) => value.extra(),
         Self::LanguagePackStringValue(value) => value.extra(),
+        Self::LogStream(value) => value.extra(),
         Self::OptionValue(value) => value.extra(),
         Self::PassportElement(value) => value.extra(),
         Self::Update(value) => value.extra(),
@@ -850,18 +934,24 @@ impl RObject for TdType {
         Self::ConnectedWebsites(value) => value.extra(),
         Self::Count(value) => value.extra(),
         Self::CustomRequestResult(value) => value.extra(),
+        Self::DatabaseStatistics(value) => value.extra(),
         Self::DeepLinkInfo(value) => value.extra(),
         Self::EmailAddressAuthenticationCodeInfo(value) => value.extra(),
         Self::Error(value) => value.extra(),
         Self::File(value) => value.extra(),
+        Self::FilePart(value) => value.extra(),
         Self::FormattedText(value) => value.extra(),
         Self::FoundMessages(value) => value.extra(),
         Self::GameHighScores(value) => value.extra(),
         Self::Hashtags(value) => value.extra(),
+        Self::HttpUrl(value) => value.extra(),
         Self::ImportedContacts(value) => value.extra(),
         Self::InlineQueryResults(value) => value.extra(),
+        Self::LanguagePackInfo(value) => value.extra(),
         Self::LanguagePackStrings(value) => value.extra(),
         Self::LocalizationTargetInfo(value) => value.extra(),
+        Self::LogTags(value) => value.extra(),
+        Self::LogVerbosityLevel(value) => value.extra(),
         Self::Message(value) => value.extra(),
         Self::Messages(value) => value.extra(),
         Self::NetworkStatistics(value) => value.extra(),
@@ -869,6 +959,7 @@ impl RObject for TdType {
         Self::OrderInfo(value) => value.extra(),
         Self::PassportAuthorizationForm(value) => value.extra(),
         Self::PassportElements(value) => value.extra(),
+        Self::PassportElementsWithErrors(value) => value.extra(),
         Self::PasswordState(value) => value.extra(),
         Self::PaymentForm(value) => value.extra(),
         Self::PaymentReceipt(value) => value.extra(),
@@ -876,6 +967,7 @@ impl RObject for TdType {
         Self::Proxies(value) => value.extra(),
         Self::Proxy(value) => value.extra(),
         Self::PublicMessageLink(value) => value.extra(),
+        Self::PushReceiverId(value) => value.extra(),
         Self::RecoveryEmailAddress(value) => value.extra(),
         Self::ScopeNotificationSettings(value) => value.extra(),
         Self::Seconds(value) => value.extra(),
@@ -900,6 +992,7 @@ impl RObject for TdType {
         Self::TestVectorStringObject(value) => value.extra(),
         Self::Text(value) => value.extra(),
         Self::TextEntities(value) => value.extra(),
+        Self::Updates(value) => value.extra(),
         Self::User(value) => value.extra(),
         Self::UserFullInfo(value) => value.extra(),
         Self::UserPrivacySettingRules(value) => value.extra(),
@@ -916,6 +1009,7 @@ impl RObject for TdType {
   fn to_json(&self) -> RTDResult<String> {
     match self {
         Self::TestUseUpdate(value) => value.to_json(),
+        Self::UpdateActiveNotifications(value) => value.to_json(),
         Self::UpdateAuthorizationState(value) => value.to_json(),
         Self::UpdateBasicGroup(value) => value.to_json(),
         Self::UpdateBasicGroupFullInfo(value) => value.to_json(),
@@ -927,8 +1021,10 @@ impl RObject for TdType {
         Self::UpdateChatIsSponsored(value) => value.to_json(),
         Self::UpdateChatLastMessage(value) => value.to_json(),
         Self::UpdateChatNotificationSettings(value) => value.to_json(),
+        Self::UpdateChatOnlineMemberCount(value) => value.to_json(),
         Self::UpdateChatOrder(value) => value.to_json(),
         Self::UpdateChatPhoto(value) => value.to_json(),
+        Self::UpdateChatPinnedMessage(value) => value.to_json(),
         Self::UpdateChatReadInbox(value) => value.to_json(),
         Self::UpdateChatReadOutbox(value) => value.to_json(),
         Self::UpdateChatReplyMarkup(value) => value.to_json(),
@@ -940,6 +1036,7 @@ impl RObject for TdType {
         Self::UpdateFile(value) => value.to_json(),
         Self::UpdateFileGenerationStart(value) => value.to_json(),
         Self::UpdateFileGenerationStop(value) => value.to_json(),
+        Self::UpdateHavePendingNotifications(value) => value.to_json(),
         Self::UpdateInstalledStickerSets(value) => value.to_json(),
         Self::UpdateLanguagePackStrings(value) => value.to_json(),
         Self::UpdateMessageContent(value) => value.to_json(),
@@ -960,7 +1057,10 @@ impl RObject for TdType {
         Self::UpdateNewMessage(value) => value.to_json(),
         Self::UpdateNewPreCheckoutQuery(value) => value.to_json(),
         Self::UpdateNewShippingQuery(value) => value.to_json(),
+        Self::UpdateNotification(value) => value.to_json(),
+        Self::UpdateNotificationGroup(value) => value.to_json(),
         Self::UpdateOption(value) => value.to_json(),
+        Self::UpdatePoll(value) => value.to_json(),
         Self::UpdateRecentStickers(value) => value.to_json(),
         Self::UpdateSavedAnimations(value) => value.to_json(),
         Self::UpdateScopeNotificationSettings(value) => value.to_json(),
@@ -980,7 +1080,9 @@ impl RObject for TdType {
       
         Self::AuthorizationState(value) => value.to_json(),
         Self::CheckChatUsernameResult(value) => value.to_json(),
+        Self::JsonValue(value) => value.to_json(),
         Self::LanguagePackStringValue(value) => value.to_json(),
+        Self::LogStream(value) => value.to_json(),
         Self::OptionValue(value) => value.to_json(),
         Self::PassportElement(value) => value.to_json(),
         Self::Update(value) => value.to_json(),
@@ -1002,18 +1104,24 @@ impl RObject for TdType {
         Self::ConnectedWebsites(value) => value.to_json(),
         Self::Count(value) => value.to_json(),
         Self::CustomRequestResult(value) => value.to_json(),
+        Self::DatabaseStatistics(value) => value.to_json(),
         Self::DeepLinkInfo(value) => value.to_json(),
         Self::EmailAddressAuthenticationCodeInfo(value) => value.to_json(),
         Self::Error(value) => value.to_json(),
         Self::File(value) => value.to_json(),
+        Self::FilePart(value) => value.to_json(),
         Self::FormattedText(value) => value.to_json(),
         Self::FoundMessages(value) => value.to_json(),
         Self::GameHighScores(value) => value.to_json(),
         Self::Hashtags(value) => value.to_json(),
+        Self::HttpUrl(value) => value.to_json(),
         Self::ImportedContacts(value) => value.to_json(),
         Self::InlineQueryResults(value) => value.to_json(),
+        Self::LanguagePackInfo(value) => value.to_json(),
         Self::LanguagePackStrings(value) => value.to_json(),
         Self::LocalizationTargetInfo(value) => value.to_json(),
+        Self::LogTags(value) => value.to_json(),
+        Self::LogVerbosityLevel(value) => value.to_json(),
         Self::Message(value) => value.to_json(),
         Self::Messages(value) => value.to_json(),
         Self::NetworkStatistics(value) => value.to_json(),
@@ -1021,6 +1129,7 @@ impl RObject for TdType {
         Self::OrderInfo(value) => value.to_json(),
         Self::PassportAuthorizationForm(value) => value.to_json(),
         Self::PassportElements(value) => value.to_json(),
+        Self::PassportElementsWithErrors(value) => value.to_json(),
         Self::PasswordState(value) => value.to_json(),
         Self::PaymentForm(value) => value.to_json(),
         Self::PaymentReceipt(value) => value.to_json(),
@@ -1028,6 +1137,7 @@ impl RObject for TdType {
         Self::Proxies(value) => value.to_json(),
         Self::Proxy(value) => value.to_json(),
         Self::PublicMessageLink(value) => value.to_json(),
+        Self::PushReceiverId(value) => value.to_json(),
         Self::RecoveryEmailAddress(value) => value.to_json(),
         Self::ScopeNotificationSettings(value) => value.to_json(),
         Self::Seconds(value) => value.to_json(),
@@ -1052,6 +1162,7 @@ impl RObject for TdType {
         Self::TestVectorStringObject(value) => value.to_json(),
         Self::Text(value) => value.to_json(),
         Self::TextEntities(value) => value.to_json(),
+        Self::Updates(value) => value.to_json(),
         Self::User(value) => value.to_json(),
         Self::UserFullInfo(value) => value.to_json(),
         Self::UserPrivacySettingRules(value) => value.to_json(),
