@@ -37,6 +37,8 @@ pub enum InputMessageContent {
   InputMessageLocation(InputMessageLocation),
   /// A photo message
   InputMessagePhoto(InputMessagePhoto),
+  /// A message with a poll. Polls can't be sent to private or secret chats
+  InputMessagePoll(InputMessagePoll),
   /// A sticker message
   InputMessageSticker(InputMessageSticker),
   /// A text message
@@ -70,6 +72,7 @@ impl<'de> Deserialize<'de> for InputMessageContent {
       (inputMessageInvoice, InputMessageInvoice);
       (inputMessageLocation, InputMessageLocation);
       (inputMessagePhoto, InputMessagePhoto);
+      (inputMessagePoll, InputMessagePoll);
       (inputMessageSticker, InputMessageSticker);
       (inputMessageText, InputMessageText);
       (inputMessageVenue, InputMessageVenue);
@@ -93,6 +96,7 @@ impl RObject for InputMessageContent {
       InputMessageContent::InputMessageInvoice(t) => t.td_name(),
       InputMessageContent::InputMessageLocation(t) => t.td_name(),
       InputMessageContent::InputMessagePhoto(t) => t.td_name(),
+      InputMessageContent::InputMessagePoll(t) => t.td_name(),
       InputMessageContent::InputMessageSticker(t) => t.td_name(),
       InputMessageContent::InputMessageText(t) => t.td_name(),
       InputMessageContent::InputMessageVenue(t) => t.td_name(),
@@ -114,6 +118,7 @@ impl RObject for InputMessageContent {
       InputMessageContent::InputMessageInvoice(t) => t.extra(),
       InputMessageContent::InputMessageLocation(t) => t.extra(),
       InputMessageContent::InputMessagePhoto(t) => t.extra(),
+      InputMessageContent::InputMessagePoll(t) => t.extra(),
       InputMessageContent::InputMessageSticker(t) => t.extra(),
       InputMessageContent::InputMessageText(t) => t.extra(),
       InputMessageContent::InputMessageVenue(t) => t.extra(),
@@ -140,6 +145,7 @@ impl InputMessageContent {
   pub fn is_input_message_invoice(&self) -> bool { if let InputMessageContent::InputMessageInvoice(_) = self { true } else { false } }
   pub fn is_input_message_location(&self) -> bool { if let InputMessageContent::InputMessageLocation(_) = self { true } else { false } }
   pub fn is_input_message_photo(&self) -> bool { if let InputMessageContent::InputMessagePhoto(_) = self { true } else { false } }
+  pub fn is_input_message_poll(&self) -> bool { if let InputMessageContent::InputMessagePoll(_) = self { true } else { false } }
   pub fn is_input_message_sticker(&self) -> bool { if let InputMessageContent::InputMessageSticker(_) = self { true } else { false } }
   pub fn is_input_message_text(&self) -> bool { if let InputMessageContent::InputMessageText(_) = self { true } else { false } }
   pub fn is_input_message_venue(&self) -> bool { if let InputMessageContent::InputMessageVenue(_) = self { true } else { false } }
@@ -156,6 +162,7 @@ impl InputMessageContent {
   pub fn on_input_message_invoice<F: FnOnce(&InputMessageInvoice)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageInvoice(t) = self { fnc(t) }; self }
   pub fn on_input_message_location<F: FnOnce(&InputMessageLocation)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageLocation(t) = self { fnc(t) }; self }
   pub fn on_input_message_photo<F: FnOnce(&InputMessagePhoto)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessagePhoto(t) = self { fnc(t) }; self }
+  pub fn on_input_message_poll<F: FnOnce(&InputMessagePoll)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessagePoll(t) = self { fnc(t) }; self }
   pub fn on_input_message_sticker<F: FnOnce(&InputMessageSticker)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageSticker(t) = self { fnc(t) }; self }
   pub fn on_input_message_text<F: FnOnce(&InputMessageText)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageText(t) = self { fnc(t) }; self }
   pub fn on_input_message_venue<F: FnOnce(&InputMessageVenue)>(&self, fnc: F) -> &Self { if let InputMessageContent::InputMessageVenue(t) = self { fnc(t) }; self }
@@ -172,6 +179,7 @@ impl InputMessageContent {
   pub fn as_input_message_invoice(&self) -> Option<&InputMessageInvoice> { if let InputMessageContent::InputMessageInvoice(t) = self { return Some(t) } None }
   pub fn as_input_message_location(&self) -> Option<&InputMessageLocation> { if let InputMessageContent::InputMessageLocation(t) = self { return Some(t) } None }
   pub fn as_input_message_photo(&self) -> Option<&InputMessagePhoto> { if let InputMessageContent::InputMessagePhoto(t) = self { return Some(t) } None }
+  pub fn as_input_message_poll(&self) -> Option<&InputMessagePoll> { if let InputMessageContent::InputMessagePoll(t) = self { return Some(t) } None }
   pub fn as_input_message_sticker(&self) -> Option<&InputMessageSticker> { if let InputMessageContent::InputMessageSticker(t) = self { return Some(t) } None }
   pub fn as_input_message_text(&self) -> Option<&InputMessageText> { if let InputMessageContent::InputMessageText(t) = self { return Some(t) } None }
   pub fn as_input_message_venue(&self) -> Option<&InputMessageVenue> { if let InputMessageContent::InputMessageVenue(t) = self { return Some(t) } None }
@@ -199,6 +207,8 @@ impl InputMessageContent {
 
   pub fn input_message_photo<T: AsRef<InputMessagePhoto>>(t: T) -> Self { InputMessageContent::InputMessagePhoto(t.as_ref().clone()) }
 
+  pub fn input_message_poll<T: AsRef<InputMessagePoll>>(t: T) -> Self { InputMessageContent::InputMessagePoll(t.as_ref().clone()) }
+
   pub fn input_message_sticker<T: AsRef<InputMessageSticker>>(t: T) -> Self { InputMessageContent::InputMessageSticker(t.as_ref().clone()) }
 
   pub fn input_message_text<T: AsRef<InputMessageText>>(t: T) -> Self { InputMessageContent::InputMessageText(t.as_ref().clone()) }
@@ -1155,6 +1165,84 @@ impl AsRef<InputMessagePhoto> for RTDInputMessagePhotoBuilder {
 
 
 
+/// A message with a poll. Polls can't be sent to private or secret chats
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct InputMessagePoll {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Poll question, 1-255 characters
+  question: String,
+  /// List of poll answer options, 2-10 strings 1-100 characters each
+  options: Vec<String>,
+  
+}
+
+impl RObject for InputMessagePoll {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "inputMessagePoll" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDInputMessageContent for InputMessagePoll {}
+
+
+
+impl InputMessagePoll {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDInputMessagePollBuilder {
+    let mut inner = InputMessagePoll::default();
+    inner.td_name = "inputMessagePoll".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDInputMessagePollBuilder { inner }
+  }
+
+  pub fn question(&self) -> &String { &self.question }
+
+  pub fn options(&self) -> &Vec<String> { &self.options }
+
+}
+
+#[doc(hidden)]
+pub struct RTDInputMessagePollBuilder {
+  inner: InputMessagePoll
+}
+
+impl RTDInputMessagePollBuilder {
+  pub fn build(&self) -> InputMessagePoll { self.inner.clone() }
+
+   
+  pub fn question<T: AsRef<str>>(&mut self, question: T) -> &mut Self {
+    self.inner.question = question.as_ref().to_string();
+    self
+  }
+
+   
+  pub fn options(&mut self, options: Vec<String>) -> &mut Self {
+    self.inner.options = options;
+    self
+  }
+
+}
+
+impl AsRef<InputMessagePoll> for InputMessagePoll {
+  fn as_ref(&self) -> &InputMessagePoll { self }
+}
+
+impl AsRef<InputMessagePoll> for RTDInputMessagePollBuilder {
+  fn as_ref(&self) -> &InputMessagePoll { &self.inner }
+}
+
+
+
+
+
+
+
 /// A sticker message
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputMessageSticker {
