@@ -55,6 +55,7 @@ pub use self::connection_state::*;
 pub use self::contact::*;
 pub use self::count::*;
 pub use self::custom_request_result::*;
+pub use self::database_statistics::*;
 pub use self::date::*;
 pub use self::dated_file::*;
 pub use self::deep_link_info::*;
@@ -66,6 +67,7 @@ pub use self::encrypted_credentials::*;
 pub use self::encrypted_passport_element::*;
 pub use self::error::*;
 pub use self::file::*;
+pub use self::file_part::*;
 pub use self::file_type::*;
 pub use self::formatted_text::*;
 pub use self::found_messages::*;
@@ -74,6 +76,7 @@ pub use self::game::*;
 pub use self::game_high_score::*;
 pub use self::game_high_scores::*;
 pub use self::hashtags::*;
+pub use self::http_url::*;
 pub use self::identity_document::*;
 pub use self::imported_contacts::*;
 pub use self::inline_keyboard_button::*;
@@ -92,6 +95,8 @@ pub use self::input_personal_document::*;
 pub use self::input_sticker::*;
 pub use self::input_thumbnail::*;
 pub use self::invoice::*;
+pub use self::json_object_member::*;
+pub use self::json_value::*;
 pub use self::keyboard_button::*;
 pub use self::keyboard_button_type::*;
 pub use self::labeled_price_part::*;
@@ -103,27 +108,42 @@ pub use self::link_state::*;
 pub use self::local_file::*;
 pub use self::localization_target_info::*;
 pub use self::location::*;
+pub use self::log_stream::*;
+pub use self::log_tags::*;
+pub use self::log_verbosity_level::*;
 pub use self::mask_point::*;
 pub use self::mask_position::*;
 pub use self::message::*;
 pub use self::message_content::*;
 pub use self::message_forward_info::*;
+pub use self::message_forward_origin::*;
 pub use self::message_sending_state::*;
 pub use self::messages::*;
 pub use self::network_statistics::*;
 pub use self::network_statistics_entry::*;
 pub use self::network_type::*;
+pub use self::notification::*;
+pub use self::notification_group::*;
+pub use self::notification_group_type::*;
 pub use self::notification_settings_scope::*;
+pub use self::notification_type::*;
 pub use self::ok::*;
 pub use self::option_value::*;
 pub use self::order_info::*;
 pub use self::page_block::*;
+pub use self::page_block_caption::*;
+pub use self::page_block_horizontal_alignment::*;
+pub use self::page_block_list_item::*;
+pub use self::page_block_related_article::*;
+pub use self::page_block_table_cell::*;
+pub use self::page_block_vertical_alignment::*;
 pub use self::passport_authorization_form::*;
 pub use self::passport_element::*;
 pub use self::passport_element_error::*;
 pub use self::passport_element_error_source::*;
 pub use self::passport_element_type::*;
 pub use self::passport_elements::*;
+pub use self::passport_elements_with_errors::*;
 pub use self::passport_required_element::*;
 pub use self::passport_suitable_element::*;
 pub use self::password_state::*;
@@ -135,11 +155,15 @@ pub use self::personal_details::*;
 pub use self::personal_document::*;
 pub use self::photo::*;
 pub use self::photo_size::*;
+pub use self::poll::*;
+pub use self::poll_option::*;
 pub use self::profile_photo::*;
 pub use self::proxies::*;
 pub use self::proxy::*;
 pub use self::proxy_type::*;
 pub use self::public_message_link::*;
+pub use self::push_message_content::*;
+pub use self::push_receiver_id::*;
 pub use self::recovery_email_address::*;
 pub use self::remote_file::*;
 pub use self::reply_markup::*;
@@ -186,11 +210,13 @@ pub use self::text_entity_type::*;
 pub use self::text_parse_mode::*;
 pub use self::top_chat_category::*;
 pub use self::update::*;
+pub use self::updates::*;
 pub use self::user::*;
 pub use self::user_full_info::*;
 pub use self::user_privacy_setting::*;
 pub use self::user_privacy_setting_rule::*;
 pub use self::user_privacy_setting_rules::*;
+pub use self::user_profile_photo::*;
 pub use self::user_profile_photos::*;
 pub use self::user_status::*;
 pub use self::user_type::*;
@@ -253,6 +279,7 @@ mod connection_state;
 mod contact;
 mod count;
 mod custom_request_result;
+mod database_statistics;
 mod date;
 mod dated_file;
 mod deep_link_info;
@@ -264,6 +291,7 @@ mod encrypted_credentials;
 mod encrypted_passport_element;
 mod error;
 mod file;
+mod file_part;
 mod file_type;
 mod formatted_text;
 mod found_messages;
@@ -272,6 +300,7 @@ mod game;
 mod game_high_score;
 mod game_high_scores;
 mod hashtags;
+mod http_url;
 mod identity_document;
 mod imported_contacts;
 mod inline_keyboard_button;
@@ -290,6 +319,8 @@ mod input_personal_document;
 mod input_sticker;
 mod input_thumbnail;
 mod invoice;
+mod json_object_member;
+mod json_value;
 mod keyboard_button;
 mod keyboard_button_type;
 mod labeled_price_part;
@@ -301,27 +332,42 @@ mod link_state;
 mod local_file;
 mod localization_target_info;
 mod location;
+mod log_stream;
+mod log_tags;
+mod log_verbosity_level;
 mod mask_point;
 mod mask_position;
 mod message;
 mod message_content;
 mod message_forward_info;
+mod message_forward_origin;
 mod message_sending_state;
 mod messages;
 mod network_statistics;
 mod network_statistics_entry;
 mod network_type;
+mod notification;
+mod notification_group;
+mod notification_group_type;
 mod notification_settings_scope;
+mod notification_type;
 mod ok;
 mod option_value;
 mod order_info;
 mod page_block;
+mod page_block_caption;
+mod page_block_horizontal_alignment;
+mod page_block_list_item;
+mod page_block_related_article;
+mod page_block_table_cell;
+mod page_block_vertical_alignment;
 mod passport_authorization_form;
 mod passport_element;
 mod passport_element_error;
 mod passport_element_error_source;
 mod passport_element_type;
 mod passport_elements;
+mod passport_elements_with_errors;
 mod passport_required_element;
 mod passport_suitable_element;
 mod password_state;
@@ -333,11 +379,15 @@ mod personal_details;
 mod personal_document;
 mod photo;
 mod photo_size;
+mod poll;
+mod poll_option;
 mod profile_photo;
 mod proxies;
 mod proxy;
 mod proxy_type;
 mod public_message_link;
+mod push_message_content;
+mod push_receiver_id;
 mod recovery_email_address;
 mod remote_file;
 mod reply_markup;
@@ -384,11 +434,13 @@ mod text_entity_type;
 mod text_parse_mode;
 mod top_chat_category;
 mod update;
+mod updates;
 mod user;
 mod user_full_info;
 mod user_privacy_setting;
 mod user_privacy_setting_rule;
 mod user_privacy_setting_rules;
+mod user_profile_photo;
 mod user_profile_photos;
 mod user_status;
 mod user_type;
