@@ -35,6 +35,8 @@ pub enum PageBlock {
   Collage(PageBlockCollage),
   /// A page cover
   Cover(PageBlockCover),
+  /// A collapsible block
+  Details(PageBlockDetails),
   /// An empty block separating a page
   Divider(PageBlockDivider),
   /// An embedded web page
@@ -45,8 +47,12 @@ pub enum PageBlock {
   Footer(PageBlockFooter),
   /// A header
   Header(PageBlockHeader),
-  /// A list of texts
+  /// A kicker
+  Kicker(PageBlockKicker),
+  /// A list of data blocks
   List(PageBlockList),
+  /// A map
+  Map(PageBlockMap),
   /// A text paragraph
   Paragraph(PageBlockParagraph),
   /// A photo
@@ -55,12 +61,16 @@ pub enum PageBlock {
   Preformatted(PageBlockPreformatted),
   /// A pull quote
   PullQuote(PageBlockPullQuote),
+  /// Related articles
+  RelatedArticles(PageBlockRelatedArticles),
   /// A slideshow
   Slideshow(PageBlockSlideshow),
   /// A subheader
   Subheader(PageBlockSubheader),
   /// The subtitle of a page
   Subtitle(PageBlockSubtitle),
+  /// A table
+  Table(PageBlockTable),
   /// The title of a page
   Title(PageBlockTitle),
   /// A video
@@ -85,19 +95,24 @@ impl<'de> Deserialize<'de> for PageBlock {
       (pageBlockChatLink, ChatLink);
       (pageBlockCollage, Collage);
       (pageBlockCover, Cover);
+      (pageBlockDetails, Details);
       (pageBlockDivider, Divider);
       (pageBlockEmbedded, Embedded);
       (pageBlockEmbeddedPost, EmbeddedPost);
       (pageBlockFooter, Footer);
       (pageBlockHeader, Header);
+      (pageBlockKicker, Kicker);
       (pageBlockList, List);
+      (pageBlockMap, Map);
       (pageBlockParagraph, Paragraph);
       (pageBlockPhoto, Photo);
       (pageBlockPreformatted, Preformatted);
       (pageBlockPullQuote, PullQuote);
+      (pageBlockRelatedArticles, RelatedArticles);
       (pageBlockSlideshow, Slideshow);
       (pageBlockSubheader, Subheader);
       (pageBlockSubtitle, Subtitle);
+      (pageBlockTable, Table);
       (pageBlockTitle, Title);
       (pageBlockVideo, Video);
 
@@ -116,19 +131,24 @@ impl RObject for PageBlock {
       PageBlock::ChatLink(t) => t.td_name(),
       PageBlock::Collage(t) => t.td_name(),
       PageBlock::Cover(t) => t.td_name(),
+      PageBlock::Details(t) => t.td_name(),
       PageBlock::Divider(t) => t.td_name(),
       PageBlock::Embedded(t) => t.td_name(),
       PageBlock::EmbeddedPost(t) => t.td_name(),
       PageBlock::Footer(t) => t.td_name(),
       PageBlock::Header(t) => t.td_name(),
+      PageBlock::Kicker(t) => t.td_name(),
       PageBlock::List(t) => t.td_name(),
+      PageBlock::Map(t) => t.td_name(),
       PageBlock::Paragraph(t) => t.td_name(),
       PageBlock::Photo(t) => t.td_name(),
       PageBlock::Preformatted(t) => t.td_name(),
       PageBlock::PullQuote(t) => t.td_name(),
+      PageBlock::RelatedArticles(t) => t.td_name(),
       PageBlock::Slideshow(t) => t.td_name(),
       PageBlock::Subheader(t) => t.td_name(),
       PageBlock::Subtitle(t) => t.td_name(),
+      PageBlock::Table(t) => t.td_name(),
       PageBlock::Title(t) => t.td_name(),
       PageBlock::Video(t) => t.td_name(),
 
@@ -145,19 +165,24 @@ impl RObject for PageBlock {
       PageBlock::ChatLink(t) => t.extra(),
       PageBlock::Collage(t) => t.extra(),
       PageBlock::Cover(t) => t.extra(),
+      PageBlock::Details(t) => t.extra(),
       PageBlock::Divider(t) => t.extra(),
       PageBlock::Embedded(t) => t.extra(),
       PageBlock::EmbeddedPost(t) => t.extra(),
       PageBlock::Footer(t) => t.extra(),
       PageBlock::Header(t) => t.extra(),
+      PageBlock::Kicker(t) => t.extra(),
       PageBlock::List(t) => t.extra(),
+      PageBlock::Map(t) => t.extra(),
       PageBlock::Paragraph(t) => t.extra(),
       PageBlock::Photo(t) => t.extra(),
       PageBlock::Preformatted(t) => t.extra(),
       PageBlock::PullQuote(t) => t.extra(),
+      PageBlock::RelatedArticles(t) => t.extra(),
       PageBlock::Slideshow(t) => t.extra(),
       PageBlock::Subheader(t) => t.extra(),
       PageBlock::Subtitle(t) => t.extra(),
+      PageBlock::Table(t) => t.extra(),
       PageBlock::Title(t) => t.extra(),
       PageBlock::Video(t) => t.extra(),
 
@@ -179,19 +204,24 @@ impl PageBlock {
   pub fn is_chat_link(&self) -> bool { if let PageBlock::ChatLink(_) = self { true } else { false } }
   pub fn is_collage(&self) -> bool { if let PageBlock::Collage(_) = self { true } else { false } }
   pub fn is_cover(&self) -> bool { if let PageBlock::Cover(_) = self { true } else { false } }
+  pub fn is_details(&self) -> bool { if let PageBlock::Details(_) = self { true } else { false } }
   pub fn is_divider(&self) -> bool { if let PageBlock::Divider(_) = self { true } else { false } }
   pub fn is_embedded(&self) -> bool { if let PageBlock::Embedded(_) = self { true } else { false } }
   pub fn is_embedded_post(&self) -> bool { if let PageBlock::EmbeddedPost(_) = self { true } else { false } }
   pub fn is_footer(&self) -> bool { if let PageBlock::Footer(_) = self { true } else { false } }
   pub fn is_header(&self) -> bool { if let PageBlock::Header(_) = self { true } else { false } }
+  pub fn is_kicker(&self) -> bool { if let PageBlock::Kicker(_) = self { true } else { false } }
   pub fn is_list(&self) -> bool { if let PageBlock::List(_) = self { true } else { false } }
+  pub fn is_map(&self) -> bool { if let PageBlock::Map(_) = self { true } else { false } }
   pub fn is_paragraph(&self) -> bool { if let PageBlock::Paragraph(_) = self { true } else { false } }
   pub fn is_photo(&self) -> bool { if let PageBlock::Photo(_) = self { true } else { false } }
   pub fn is_preformatted(&self) -> bool { if let PageBlock::Preformatted(_) = self { true } else { false } }
   pub fn is_pull_quote(&self) -> bool { if let PageBlock::PullQuote(_) = self { true } else { false } }
+  pub fn is_related_articles(&self) -> bool { if let PageBlock::RelatedArticles(_) = self { true } else { false } }
   pub fn is_slideshow(&self) -> bool { if let PageBlock::Slideshow(_) = self { true } else { false } }
   pub fn is_subheader(&self) -> bool { if let PageBlock::Subheader(_) = self { true } else { false } }
   pub fn is_subtitle(&self) -> bool { if let PageBlock::Subtitle(_) = self { true } else { false } }
+  pub fn is_table(&self) -> bool { if let PageBlock::Table(_) = self { true } else { false } }
   pub fn is_title(&self) -> bool { if let PageBlock::Title(_) = self { true } else { false } }
   pub fn is_video(&self) -> bool { if let PageBlock::Video(_) = self { true } else { false } }
 
@@ -203,19 +233,24 @@ impl PageBlock {
   pub fn on_chat_link<F: FnOnce(&PageBlockChatLink)>(&self, fnc: F) -> &Self { if let PageBlock::ChatLink(t) = self { fnc(t) }; self }
   pub fn on_collage<F: FnOnce(&PageBlockCollage)>(&self, fnc: F) -> &Self { if let PageBlock::Collage(t) = self { fnc(t) }; self }
   pub fn on_cover<F: FnOnce(&PageBlockCover)>(&self, fnc: F) -> &Self { if let PageBlock::Cover(t) = self { fnc(t) }; self }
+  pub fn on_details<F: FnOnce(&PageBlockDetails)>(&self, fnc: F) -> &Self { if let PageBlock::Details(t) = self { fnc(t) }; self }
   pub fn on_divider<F: FnOnce(&PageBlockDivider)>(&self, fnc: F) -> &Self { if let PageBlock::Divider(t) = self { fnc(t) }; self }
   pub fn on_embedded<F: FnOnce(&PageBlockEmbedded)>(&self, fnc: F) -> &Self { if let PageBlock::Embedded(t) = self { fnc(t) }; self }
   pub fn on_embedded_post<F: FnOnce(&PageBlockEmbeddedPost)>(&self, fnc: F) -> &Self { if let PageBlock::EmbeddedPost(t) = self { fnc(t) }; self }
   pub fn on_footer<F: FnOnce(&PageBlockFooter)>(&self, fnc: F) -> &Self { if let PageBlock::Footer(t) = self { fnc(t) }; self }
   pub fn on_header<F: FnOnce(&PageBlockHeader)>(&self, fnc: F) -> &Self { if let PageBlock::Header(t) = self { fnc(t) }; self }
+  pub fn on_kicker<F: FnOnce(&PageBlockKicker)>(&self, fnc: F) -> &Self { if let PageBlock::Kicker(t) = self { fnc(t) }; self }
   pub fn on_list<F: FnOnce(&PageBlockList)>(&self, fnc: F) -> &Self { if let PageBlock::List(t) = self { fnc(t) }; self }
+  pub fn on_map<F: FnOnce(&PageBlockMap)>(&self, fnc: F) -> &Self { if let PageBlock::Map(t) = self { fnc(t) }; self }
   pub fn on_paragraph<F: FnOnce(&PageBlockParagraph)>(&self, fnc: F) -> &Self { if let PageBlock::Paragraph(t) = self { fnc(t) }; self }
   pub fn on_photo<F: FnOnce(&PageBlockPhoto)>(&self, fnc: F) -> &Self { if let PageBlock::Photo(t) = self { fnc(t) }; self }
   pub fn on_preformatted<F: FnOnce(&PageBlockPreformatted)>(&self, fnc: F) -> &Self { if let PageBlock::Preformatted(t) = self { fnc(t) }; self }
   pub fn on_pull_quote<F: FnOnce(&PageBlockPullQuote)>(&self, fnc: F) -> &Self { if let PageBlock::PullQuote(t) = self { fnc(t) }; self }
+  pub fn on_related_articles<F: FnOnce(&PageBlockRelatedArticles)>(&self, fnc: F) -> &Self { if let PageBlock::RelatedArticles(t) = self { fnc(t) }; self }
   pub fn on_slideshow<F: FnOnce(&PageBlockSlideshow)>(&self, fnc: F) -> &Self { if let PageBlock::Slideshow(t) = self { fnc(t) }; self }
   pub fn on_subheader<F: FnOnce(&PageBlockSubheader)>(&self, fnc: F) -> &Self { if let PageBlock::Subheader(t) = self { fnc(t) }; self }
   pub fn on_subtitle<F: FnOnce(&PageBlockSubtitle)>(&self, fnc: F) -> &Self { if let PageBlock::Subtitle(t) = self { fnc(t) }; self }
+  pub fn on_table<F: FnOnce(&PageBlockTable)>(&self, fnc: F) -> &Self { if let PageBlock::Table(t) = self { fnc(t) }; self }
   pub fn on_title<F: FnOnce(&PageBlockTitle)>(&self, fnc: F) -> &Self { if let PageBlock::Title(t) = self { fnc(t) }; self }
   pub fn on_video<F: FnOnce(&PageBlockVideo)>(&self, fnc: F) -> &Self { if let PageBlock::Video(t) = self { fnc(t) }; self }
 
@@ -227,19 +262,24 @@ impl PageBlock {
   pub fn as_chat_link(&self) -> Option<&PageBlockChatLink> { if let PageBlock::ChatLink(t) = self { return Some(t) } None }
   pub fn as_collage(&self) -> Option<&PageBlockCollage> { if let PageBlock::Collage(t) = self { return Some(t) } None }
   pub fn as_cover(&self) -> Option<&PageBlockCover> { if let PageBlock::Cover(t) = self { return Some(t) } None }
+  pub fn as_details(&self) -> Option<&PageBlockDetails> { if let PageBlock::Details(t) = self { return Some(t) } None }
   pub fn as_divider(&self) -> Option<&PageBlockDivider> { if let PageBlock::Divider(t) = self { return Some(t) } None }
   pub fn as_embedded(&self) -> Option<&PageBlockEmbedded> { if let PageBlock::Embedded(t) = self { return Some(t) } None }
   pub fn as_embedded_post(&self) -> Option<&PageBlockEmbeddedPost> { if let PageBlock::EmbeddedPost(t) = self { return Some(t) } None }
   pub fn as_footer(&self) -> Option<&PageBlockFooter> { if let PageBlock::Footer(t) = self { return Some(t) } None }
   pub fn as_header(&self) -> Option<&PageBlockHeader> { if let PageBlock::Header(t) = self { return Some(t) } None }
+  pub fn as_kicker(&self) -> Option<&PageBlockKicker> { if let PageBlock::Kicker(t) = self { return Some(t) } None }
   pub fn as_list(&self) -> Option<&PageBlockList> { if let PageBlock::List(t) = self { return Some(t) } None }
+  pub fn as_map(&self) -> Option<&PageBlockMap> { if let PageBlock::Map(t) = self { return Some(t) } None }
   pub fn as_paragraph(&self) -> Option<&PageBlockParagraph> { if let PageBlock::Paragraph(t) = self { return Some(t) } None }
   pub fn as_photo(&self) -> Option<&PageBlockPhoto> { if let PageBlock::Photo(t) = self { return Some(t) } None }
   pub fn as_preformatted(&self) -> Option<&PageBlockPreformatted> { if let PageBlock::Preformatted(t) = self { return Some(t) } None }
   pub fn as_pull_quote(&self) -> Option<&PageBlockPullQuote> { if let PageBlock::PullQuote(t) = self { return Some(t) } None }
+  pub fn as_related_articles(&self) -> Option<&PageBlockRelatedArticles> { if let PageBlock::RelatedArticles(t) = self { return Some(t) } None }
   pub fn as_slideshow(&self) -> Option<&PageBlockSlideshow> { if let PageBlock::Slideshow(t) = self { return Some(t) } None }
   pub fn as_subheader(&self) -> Option<&PageBlockSubheader> { if let PageBlock::Subheader(t) = self { return Some(t) } None }
   pub fn as_subtitle(&self) -> Option<&PageBlockSubtitle> { if let PageBlock::Subtitle(t) = self { return Some(t) } None }
+  pub fn as_table(&self) -> Option<&PageBlockTable> { if let PageBlock::Table(t) = self { return Some(t) } None }
   pub fn as_title(&self) -> Option<&PageBlockTitle> { if let PageBlock::Title(t) = self { return Some(t) } None }
   pub fn as_video(&self) -> Option<&PageBlockVideo> { if let PageBlock::Video(t) = self { return Some(t) } None }
 
@@ -261,6 +301,8 @@ impl PageBlock {
 
   pub fn cover<T: AsRef<PageBlockCover>>(t: T) -> Self { PageBlock::Cover(t.as_ref().clone()) }
 
+  pub fn details<T: AsRef<PageBlockDetails>>(t: T) -> Self { PageBlock::Details(t.as_ref().clone()) }
+
   pub fn divider<T: AsRef<PageBlockDivider>>(t: T) -> Self { PageBlock::Divider(t.as_ref().clone()) }
 
   pub fn embedded<T: AsRef<PageBlockEmbedded>>(t: T) -> Self { PageBlock::Embedded(t.as_ref().clone()) }
@@ -271,8 +313,12 @@ impl PageBlock {
 
   pub fn header<T: AsRef<PageBlockHeader>>(t: T) -> Self { PageBlock::Header(t.as_ref().clone()) }
 
+  pub fn kicker<T: AsRef<PageBlockKicker>>(t: T) -> Self { PageBlock::Kicker(t.as_ref().clone()) }
+
   pub fn list<T: AsRef<PageBlockList>>(t: T) -> Self { PageBlock::List(t.as_ref().clone()) }
 
+  pub fn map<T: AsRef<PageBlockMap>>(t: T) -> Self { PageBlock::Map(t.as_ref().clone()) }
+
   pub fn paragraph<T: AsRef<PageBlockParagraph>>(t: T) -> Self { PageBlock::Paragraph(t.as_ref().clone()) }
 
   pub fn photo<T: AsRef<PageBlockPhoto>>(t: T) -> Self { PageBlock::Photo(t.as_ref().clone()) }
@@ -281,12 +327,16 @@ impl PageBlock {
 
   pub fn pull_quote<T: AsRef<PageBlockPullQuote>>(t: T) -> Self { PageBlock::PullQuote(t.as_ref().clone()) }
 
+  pub fn related_articles<T: AsRef<PageBlockRelatedArticles>>(t: T) -> Self { PageBlock::RelatedArticles(t.as_ref().clone()) }
+
   pub fn slideshow<T: AsRef<PageBlockSlideshow>>(t: T) -> Self { PageBlock::Slideshow(t.as_ref().clone()) }
 
   pub fn subheader<T: AsRef<PageBlockSubheader>>(t: T) -> Self { PageBlock::Subheader(t.as_ref().clone()) }
 
   pub fn subtitle<T: AsRef<PageBlockSubtitle>>(t: T) -> Self { PageBlock::Subtitle(t.as_ref().clone()) }
 
+  pub fn table<T: AsRef<PageBlockTable>>(t: T) -> Self { PageBlock::Table(t.as_ref().clone()) }
+
   pub fn title<T: AsRef<PageBlockTitle>>(t: T) -> Self { PageBlock::Title(t.as_ref().clone()) }
 
   pub fn video<T: AsRef<PageBlockVideo>>(t: T) -> Self { PageBlock::Video(t.as_ref().clone()) }
@@ -383,7 +433,7 @@ pub struct PageBlockAnimation {
   /// Animation file; may be null
   animation: Option<Animation>,
   /// Animation caption
-  caption: RichText,
+  caption: PageBlockCaption,
   /// True, if the animation should be played automatically
   need_autoplay: bool,
   
@@ -411,7 +461,7 @@ impl PageBlockAnimation {
 
   pub fn animation(&self) -> &Option<Animation> { &self.animation }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
   pub fn need_autoplay(&self) -> bool { self.need_autoplay }
 
@@ -432,7 +482,7 @@ impl RTDPageBlockAnimationBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -471,7 +521,7 @@ pub struct PageBlockAudio {
   /// Audio file; may be null
   audio: Option<Audio>,
   /// Audio file caption
-  caption: RichText,
+  caption: PageBlockCaption,
   
 }
 
@@ -497,7 +547,7 @@ impl PageBlockAudio {
 
   pub fn audio(&self) -> &Option<Audio> { &self.audio }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
 }
 
@@ -516,7 +566,7 @@ impl RTDPageBlockAudioBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -626,8 +676,8 @@ pub struct PageBlockBlockQuote {
   extra: Option<String>,
   /// Quote text
   text: RichText,
-  /// Quote caption
-  caption: RichText,
+  /// Quote credit
+  credit: RichText,
   
 }
 
@@ -653,7 +703,7 @@ impl PageBlockBlockQuote {
 
   pub fn text(&self) -> &RichText { &self.text }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn credit(&self) -> &RichText { &self.credit }
 
 }
 
@@ -672,8 +722,8 @@ impl RTDPageBlockBlockQuoteBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
-    self.inner.caption = caption.as_ref().clone();
+  pub fn credit<T: AsRef<RichText>>(&mut self, credit: T) -> &mut Self {
+    self.inner.credit = credit.as_ref().clone();
     self
   }
 
@@ -793,7 +843,7 @@ pub struct PageBlockCollage {
   /// Collage item contents
   page_blocks: Vec<PageBlock>,
   /// Block caption
-  caption: RichText,
+  caption: PageBlockCaption,
   
 }
 
@@ -819,7 +869,7 @@ impl PageBlockCollage {
 
   pub fn page_blocks(&self) -> &Vec<PageBlock> { &self.page_blocks }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
 }
 
@@ -838,7 +888,7 @@ impl RTDPageBlockCollageBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -927,6 +977,94 @@ impl AsRef<PageBlockCover> for RTDPageBlockCoverBuilder {
 
 
 
+/// A collapsible block
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockDetails {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Always visible heading for the block
+  header: RichText,
+  /// Block contents
+  page_blocks: Vec<PageBlock>,
+  /// True, if the block is open by default
+  is_open: bool,
+  
+}
+
+impl RObject for PageBlockDetails {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockDetails" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockDetails {}
+
+
+
+impl PageBlockDetails {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockDetailsBuilder {
+    let mut inner = PageBlockDetails::default();
+    inner.td_name = "pageBlockDetails".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockDetailsBuilder { inner }
+  }
+
+  pub fn header(&self) -> &RichText { &self.header }
+
+  pub fn page_blocks(&self) -> &Vec<PageBlock> { &self.page_blocks }
+
+  pub fn is_open(&self) -> bool { self.is_open }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockDetailsBuilder {
+  inner: PageBlockDetails
+}
+
+impl RTDPageBlockDetailsBuilder {
+  pub fn build(&self) -> PageBlockDetails { self.inner.clone() }
+
+   
+  pub fn header<T: AsRef<RichText>>(&mut self, header: T) -> &mut Self {
+    self.inner.header = header.as_ref().clone();
+    self
+  }
+
+   
+  pub fn page_blocks(&mut self, page_blocks: Vec<PageBlock>) -> &mut Self {
+    self.inner.page_blocks = page_blocks;
+    self
+  }
+
+   
+  pub fn is_open(&mut self, is_open: bool) -> &mut Self {
+    self.inner.is_open = is_open;
+    self
+  }
+
+}
+
+impl AsRef<PageBlockDetails> for PageBlockDetails {
+  fn as_ref(&self) -> &PageBlockDetails { self }
+}
+
+impl AsRef<PageBlockDetails> for RTDPageBlockDetailsBuilder {
+  fn as_ref(&self) -> &PageBlockDetails { &self.inner }
+}
+
+
+
+
+
+
+
 /// An empty block separating a page
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PageBlockDivider {
@@ -1000,12 +1138,12 @@ pub struct PageBlockEmbedded {
   html: String,
   /// Poster photo, if available; may be null
   poster_photo: Option<Photo>,
-  /// Block width
+  /// Block width, 0 if unknown
   width: i64,
-  /// Block height
+  /// Block height, 0 if unknown
   height: i64,
   /// Block caption
-  caption: RichText,
+  caption: PageBlockCaption,
   /// True, if the block should be full width
   is_full_width: bool,
   /// True, if scrolling should be allowed
@@ -1043,7 +1181,7 @@ impl PageBlockEmbedded {
 
   pub fn height(&self) -> i64 { self.height }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
   pub fn is_full_width(&self) -> bool { self.is_full_width }
 
@@ -1090,7 +1228,7 @@ impl RTDPageBlockEmbeddedBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -1143,7 +1281,7 @@ pub struct PageBlockEmbeddedPost {
   /// Post content
   page_blocks: Vec<PageBlock>,
   /// Post caption
-  caption: RichText,
+  caption: PageBlockCaption,
   
 }
 
@@ -1177,7 +1315,7 @@ impl PageBlockEmbeddedPost {
 
   pub fn page_blocks(&self) -> &Vec<PageBlock> { &self.page_blocks }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
 }
 
@@ -1220,7 +1358,7 @@ impl RTDPageBlockEmbeddedPostBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -1377,7 +1515,75 @@ impl AsRef<PageBlockHeader> for RTDPageBlockHeaderBuilder {
 
 
 
-/// A list of texts
+/// A kicker
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockKicker {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Kicker
+  kicker: RichText,
+  
+}
+
+impl RObject for PageBlockKicker {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockKicker" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockKicker {}
+
+
+
+impl PageBlockKicker {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockKickerBuilder {
+    let mut inner = PageBlockKicker::default();
+    inner.td_name = "pageBlockKicker".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockKickerBuilder { inner }
+  }
+
+  pub fn kicker(&self) -> &RichText { &self.kicker }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockKickerBuilder {
+  inner: PageBlockKicker
+}
+
+impl RTDPageBlockKickerBuilder {
+  pub fn build(&self) -> PageBlockKicker { self.inner.clone() }
+
+   
+  pub fn kicker<T: AsRef<RichText>>(&mut self, kicker: T) -> &mut Self {
+    self.inner.kicker = kicker.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<PageBlockKicker> for PageBlockKicker {
+  fn as_ref(&self) -> &PageBlockKicker { self }
+}
+
+impl AsRef<PageBlockKicker> for RTDPageBlockKickerBuilder {
+  fn as_ref(&self) -> &PageBlockKicker { &self.inner }
+}
+
+
+
+
+
+
+
+/// A list of data blocks
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PageBlockList {
   #[doc(hidden)]
@@ -1386,10 +1592,8 @@ pub struct PageBlockList {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Texts
-  items: Vec<RichText>,
-  /// True, if the items should be marked with numbers
-  is_ordered: bool,
+  /// The items of the list
+  items: Vec<PageBlockListItem>,
   
 }
 
@@ -1413,9 +1617,7 @@ impl PageBlockList {
     RTDPageBlockListBuilder { inner }
   }
 
-  pub fn items(&self) -> &Vec<RichText> { &self.items }
-
-  pub fn is_ordered(&self) -> bool { self.is_ordered }
+  pub fn items(&self) -> &Vec<PageBlockListItem> { &self.items }
 
 }
 
@@ -1428,17 +1630,11 @@ impl RTDPageBlockListBuilder {
   pub fn build(&self) -> PageBlockList { self.inner.clone() }
 
    
-  pub fn items(&mut self, items: Vec<RichText>) -> &mut Self {
+  pub fn items(&mut self, items: Vec<PageBlockListItem>) -> &mut Self {
     self.inner.items = items;
     self
   }
 
-   
-  pub fn is_ordered(&mut self, is_ordered: bool) -> &mut Self {
-    self.inner.is_ordered = is_ordered;
-    self
-  }
-
 }
 
 impl AsRef<PageBlockList> for PageBlockList {
@@ -1455,6 +1651,114 @@ impl AsRef<PageBlockList> for RTDPageBlockListBuilder {
 
 
 
+/// A map
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockMap {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Location of the map center
+  location: Location,
+  /// Map zoom level
+  zoom: i64,
+  /// Map width
+  width: i64,
+  /// Map height
+  height: i64,
+  /// Block caption
+  caption: PageBlockCaption,
+  
+}
+
+impl RObject for PageBlockMap {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockMap" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockMap {}
+
+
+
+impl PageBlockMap {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockMapBuilder {
+    let mut inner = PageBlockMap::default();
+    inner.td_name = "pageBlockMap".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockMapBuilder { inner }
+  }
+
+  pub fn location(&self) -> &Location { &self.location }
+
+  pub fn zoom(&self) -> i64 { self.zoom }
+
+  pub fn width(&self) -> i64 { self.width }
+
+  pub fn height(&self) -> i64 { self.height }
+
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockMapBuilder {
+  inner: PageBlockMap
+}
+
+impl RTDPageBlockMapBuilder {
+  pub fn build(&self) -> PageBlockMap { self.inner.clone() }
+
+   
+  pub fn location<T: AsRef<Location>>(&mut self, location: T) -> &mut Self {
+    self.inner.location = location.as_ref().clone();
+    self
+  }
+
+   
+  pub fn zoom(&mut self, zoom: i64) -> &mut Self {
+    self.inner.zoom = zoom;
+    self
+  }
+
+   
+  pub fn width(&mut self, width: i64) -> &mut Self {
+    self.inner.width = width;
+    self
+  }
+
+   
+  pub fn height(&mut self, height: i64) -> &mut Self {
+    self.inner.height = height;
+    self
+  }
+
+   
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
+    self.inner.caption = caption.as_ref().clone();
+    self
+  }
+
+}
+
+impl AsRef<PageBlockMap> for PageBlockMap {
+  fn as_ref(&self) -> &PageBlockMap { self }
+}
+
+impl AsRef<PageBlockMap> for RTDPageBlockMapBuilder {
+  fn as_ref(&self) -> &PageBlockMap { &self.inner }
+}
+
+
+
+
+
+
+
 /// A text paragraph
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PageBlockParagraph {
@@ -1535,7 +1839,9 @@ pub struct PageBlockPhoto {
   /// Photo file; may be null
   photo: Option<Photo>,
   /// Photo caption
-  caption: RichText,
+  caption: PageBlockCaption,
+  /// URL that needs to be opened when the photo is clicked
+  url: String,
   
 }
 
@@ -1561,7 +1867,9 @@ impl PageBlockPhoto {
 
   pub fn photo(&self) -> &Option<Photo> { &self.photo }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
+
+  pub fn url(&self) -> &String { &self.url }
 
 }
 
@@ -1580,11 +1888,17 @@ impl RTDPageBlockPhotoBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
 
+   
+  pub fn url<T: AsRef<str>>(&mut self, url: T) -> &mut Self {
+    self.inner.url = url.as_ref().to_string();
+    self
+  }
+
 }
 
 impl AsRef<PageBlockPhoto> for PageBlockPhoto {
@@ -1690,8 +2004,8 @@ pub struct PageBlockPullQuote {
   extra: Option<String>,
   /// Quote text
   text: RichText,
-  /// Quote caption
-  caption: RichText,
+  /// Quote credit
+  credit: RichText,
   
 }
 
@@ -1717,7 +2031,7 @@ impl PageBlockPullQuote {
 
   pub fn text(&self) -> &RichText { &self.text }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn credit(&self) -> &RichText { &self.credit }
 
 }
 
@@ -1736,8 +2050,8 @@ impl RTDPageBlockPullQuoteBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
-    self.inner.caption = caption.as_ref().clone();
+  pub fn credit<T: AsRef<RichText>>(&mut self, credit: T) -> &mut Self {
+    self.inner.credit = credit.as_ref().clone();
     self
   }
 
@@ -1757,6 +2071,84 @@ impl AsRef<PageBlockPullQuote> for RTDPageBlockPullQuoteBuilder {
 
 
 
+/// Related articles
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockRelatedArticles {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Block header
+  header: RichText,
+  /// List of related articles
+  articles: Vec<PageBlockRelatedArticle>,
+  
+}
+
+impl RObject for PageBlockRelatedArticles {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockRelatedArticles" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockRelatedArticles {}
+
+
+
+impl PageBlockRelatedArticles {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockRelatedArticlesBuilder {
+    let mut inner = PageBlockRelatedArticles::default();
+    inner.td_name = "pageBlockRelatedArticles".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockRelatedArticlesBuilder { inner }
+  }
+
+  pub fn header(&self) -> &RichText { &self.header }
+
+  pub fn articles(&self) -> &Vec<PageBlockRelatedArticle> { &self.articles }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockRelatedArticlesBuilder {
+  inner: PageBlockRelatedArticles
+}
+
+impl RTDPageBlockRelatedArticlesBuilder {
+  pub fn build(&self) -> PageBlockRelatedArticles { self.inner.clone() }
+
+   
+  pub fn header<T: AsRef<RichText>>(&mut self, header: T) -> &mut Self {
+    self.inner.header = header.as_ref().clone();
+    self
+  }
+
+   
+  pub fn articles(&mut self, articles: Vec<PageBlockRelatedArticle>) -> &mut Self {
+    self.inner.articles = articles;
+    self
+  }
+
+}
+
+impl AsRef<PageBlockRelatedArticles> for PageBlockRelatedArticles {
+  fn as_ref(&self) -> &PageBlockRelatedArticles { self }
+}
+
+impl AsRef<PageBlockRelatedArticles> for RTDPageBlockRelatedArticlesBuilder {
+  fn as_ref(&self) -> &PageBlockRelatedArticles { &self.inner }
+}
+
+
+
+
+
+
+
 /// A slideshow
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PageBlockSlideshow {
@@ -1769,7 +2161,7 @@ pub struct PageBlockSlideshow {
   /// Slideshow item contents
   page_blocks: Vec<PageBlock>,
   /// Block caption
-  caption: RichText,
+  caption: PageBlockCaption,
   
 }
 
@@ -1795,7 +2187,7 @@ impl PageBlockSlideshow {
 
   pub fn page_blocks(&self) -> &Vec<PageBlock> { &self.page_blocks }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
 }
 
@@ -1814,7 +2206,7 @@ impl RTDPageBlockSlideshowBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
@@ -1971,6 +2363,104 @@ impl AsRef<PageBlockSubtitle> for RTDPageBlockSubtitleBuilder {
 
 
 
+/// A table
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct PageBlockTable {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Table caption
+  caption: RichText,
+  /// Table cells
+  cells: Vec<Vec<PageBlockTableCell>>,
+  /// True, if the table is bordered
+  is_bordered: bool,
+  /// True, if the table is striped
+  is_striped: bool,
+  
+}
+
+impl RObject for PageBlockTable {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "pageBlockTable" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDPageBlock for PageBlockTable {}
+
+
+
+impl PageBlockTable {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDPageBlockTableBuilder {
+    let mut inner = PageBlockTable::default();
+    inner.td_name = "pageBlockTable".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDPageBlockTableBuilder { inner }
+  }
+
+  pub fn caption(&self) -> &RichText { &self.caption }
+
+  pub fn cells(&self) -> &Vec<Vec<PageBlockTableCell>> { &self.cells }
+
+  pub fn is_bordered(&self) -> bool { self.is_bordered }
+
+  pub fn is_striped(&self) -> bool { self.is_striped }
+
+}
+
+#[doc(hidden)]
+pub struct RTDPageBlockTableBuilder {
+  inner: PageBlockTable
+}
+
+impl RTDPageBlockTableBuilder {
+  pub fn build(&self) -> PageBlockTable { self.inner.clone() }
+
+   
+  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+    self.inner.caption = caption.as_ref().clone();
+    self
+  }
+
+   
+  pub fn cells(&mut self, cells: Vec<Vec<PageBlockTableCell>>) -> &mut Self {
+    self.inner.cells = cells;
+    self
+  }
+
+   
+  pub fn is_bordered(&mut self, is_bordered: bool) -> &mut Self {
+    self.inner.is_bordered = is_bordered;
+    self
+  }
+
+   
+  pub fn is_striped(&mut self, is_striped: bool) -> &mut Self {
+    self.inner.is_striped = is_striped;
+    self
+  }
+
+}
+
+impl AsRef<PageBlockTable> for PageBlockTable {
+  fn as_ref(&self) -> &PageBlockTable { self }
+}
+
+impl AsRef<PageBlockTable> for RTDPageBlockTableBuilder {
+  fn as_ref(&self) -> &PageBlockTable { &self.inner }
+}
+
+
+
+
+
+
+
 /// The title of a page
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct PageBlockTitle {
@@ -2051,7 +2541,7 @@ pub struct PageBlockVideo {
   /// Video file; may be null
   video: Option<Video>,
   /// Video caption
-  caption: RichText,
+  caption: PageBlockCaption,
   /// True, if the video should be played automatically
   need_autoplay: bool,
   /// True, if the video should be looped
@@ -2081,7 +2571,7 @@ impl PageBlockVideo {
 
   pub fn video(&self) -> &Option<Video> { &self.video }
 
-  pub fn caption(&self) -> &RichText { &self.caption }
+  pub fn caption(&self) -> &PageBlockCaption { &self.caption }
 
   pub fn need_autoplay(&self) -> bool { self.need_autoplay }
 
@@ -2104,7 +2594,7 @@ impl RTDPageBlockVideoBuilder {
   }
 
    
-  pub fn caption<T: AsRef<RichText>>(&mut self, caption: T) -> &mut Self {
+  pub fn caption<T: AsRef<PageBlockCaption>>(&mut self, caption: T) -> &mut Self {
     self.inner.caption = caption.as_ref().clone();
     self
   }
