@@ -15,8 +15,6 @@ pub struct Photo {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Photo identifier; 0 for deleted photos
-  id: isize,
   /// True, if stickers were added to the photo
   has_stickers: bool,
   /// Available variants of the photo, in different sizes
@@ -41,8 +39,6 @@ impl Photo {
     RTDPhotoBuilder { inner }
   }
 
-  pub fn id(&self) -> isize { self.id }
-
   pub fn has_stickers(&self) -> bool { self.has_stickers }
 
   pub fn sizes(&self) -> &Vec<PhotoSize> { &self.sizes }
@@ -58,12 +54,6 @@ impl RTDPhotoBuilder {
   pub fn build(&self) -> Photo { self.inner.clone() }
 
    
-  pub fn id(&mut self, id: isize) -> &mut Self {
-    self.inner.id = id;
-    self
-  }
-
-   
   pub fn has_stickers(&mut self, has_stickers: bool) -> &mut Self {
     self.inner.has_stickers = has_stickers;
     self
