@@ -35,6 +35,8 @@ pub struct User {
   incoming_link: LinkState,
   /// True, if the user is verified
   is_verified: bool,
+  /// True, if the user is Telegram support account
+  is_support: bool,
   /// If non-empty, it contains the reason why access to this user must be restricted. The format of the string is "{type}: {description}". {type} contains the type of the restriction and at least one of the suffixes "-all", "-ios", "-android", or "-wp", which describe the platforms on which access should be restricted. (For example, "terms-ios-android". {description} contains a human-readable description of the restriction, which can be shown to the user)
   restriction_reason: String,
   /// If false, the user is inaccessible, and the only information known about the user is inside this class. It can't be passed to any method except GetUser
@@ -83,6 +85,8 @@ impl User {
 
   pub fn is_verified(&self) -> bool { self.is_verified }
 
+  pub fn is_support(&self) -> bool { self.is_support }
+
   pub fn restriction_reason(&self) -> &String { &self.restriction_reason }
 
   pub fn have_access(&self) -> bool { self.have_access }
@@ -162,6 +166,12 @@ impl RTDUserBuilder {
   }
 
    
+  pub fn is_support(&mut self, is_support: bool) -> &mut Self {
+    self.inner.is_support = is_support;
+    self
+  }
+
+   
   pub fn restriction_reason<T: AsRef<str>>(&mut self, restriction_reason: T) -> &mut Self {
     self.inner.restriction_reason = restriction_reason.as_ref().to_string();
     self
