@@ -25,14 +25,12 @@ pub struct Video {
   file_name: String,
   /// MIME type of the file; as defined by the sender
   mime_type: String,
-  /// True, if stickers were added to the video. The list of corresponding sticker sets can be received using getAttachedStickerSets
+  /// True, if stickers were added to the photo
   has_stickers: bool,
-  /// True, if the video is supposed to be streamed
+  /// True, if the video should be tried to be streamed
   supports_streaming: bool,
-  /// Video minithumbnail; may be null
-  minithumbnail: Option<Minithumbnail>,
-  /// Video thumbnail in JPEG or MPEG4 format; as defined by the sender; may be null
-  thumbnail: Option<Thumbnail>,
+  /// Video thumbnail; as defined by the sender; may be null
+  thumbnail: Option<PhotoSize>,
   /// File containing the video
   video: File,
   
@@ -69,9 +67,7 @@ impl Video {
 
   pub fn supports_streaming(&self) -> bool { self.supports_streaming }
 
-  pub fn minithumbnail(&self) -> &Option<Minithumbnail> { &self.minithumbnail }
-
-  pub fn thumbnail(&self) -> &Option<Thumbnail> { &self.thumbnail }
+  pub fn thumbnail(&self) -> &Option<PhotoSize> { &self.thumbnail }
 
   pub fn video(&self) -> &File { &self.video }
 
@@ -128,13 +124,7 @@ impl RTDVideoBuilder {
   }
 
    
-  pub fn minithumbnail<T: AsRef<Minithumbnail>>(&mut self, minithumbnail: T) -> &mut Self {
-    self.inner.minithumbnail = Some(minithumbnail.as_ref().clone());
-    self
-  }
-
-   
-  pub fn thumbnail<T: AsRef<Thumbnail>>(&mut self, thumbnail: T) -> &mut Self {
+  pub fn thumbnail<T: AsRef<PhotoSize>>(&mut self, thumbnail: T) -> &mut Self {
     self.inner.thumbnail = Some(thumbnail.as_ref().clone());
     self
   }
